@@ -76,16 +76,9 @@
 #' @export
 get_sids <- function(identifier, namespace = 'cid', domain = 'compound', searchtype = NULL, options = NULL) {
 
-  # Try to get the response and parse JSON
-  # Assuming 'get_json' is a function you've previously defined, similar to your Python environment
-  result <- lapply(identifier, function(x){
-    tmp <- get_json(identifier = x, namespace, domain, 'sids', searchtype, options)
-    class(tmp) <- NULL
-    return(tmp)
-  })
-
+  # Initialize result list
   SIDs_List <- list(
-    result = result,
+    result = list(),
     request_args = list(
       namespace = namespace,
       identifier = identifier,
@@ -95,6 +88,44 @@ get_sids <- function(identifier, namespace = 'cid', domain = 'compound', searcht
     error = NULL
   )
 
+  # Attempt to get the response and handle errors gracefully
+  result <- lapply(identifier, function(x) {
+    # Use tryCatch to handle potential errors
+    response <- tryCatch({
+      tmp <- get_json(identifier = x, namespace, domain, 'sids', searchtype, options)
+      class(tmp) <- NULL
+      SIDs_List$success <- c(SIDs_List$success, TRUE)
+      tmp
+    }, error = function(e) {
+      # Capture the error message
+      error_message <- conditionMessage(e)
+
+      # Determine the error type and assign an appropriate message
+      if (grepl("Timeout", error_message, ignore.case = TRUE)) {
+        error_message <- paste0("Request timeout: The server did not respond in time for identifier '", x, "'. Please try again later.")
+      } else if (grepl("Could not resolve host", error_message, ignore.case = TRUE) ||
+                 grepl("InternetOpenUrl", error_message, ignore.case = TRUE)) {
+        error_message <- "Network error: Could not connect to the server. Please check your internet connection and try again."
+      } else if (grepl("HTTP error", error_message, ignore.case = TRUE)) {
+        error_message <- paste0("HTTP error: The server returned an error for identifier '", x, "'. Please check the server status or try again later.")
+      } else {
+        error_message <- paste0("An unknown error occurred for identifier '", x, "': ", error_message)
+      }
+
+      # Append error message to SIDs_List$error
+      SIDs_List$error <- c(SIDs_List$error, error_message)
+      SIDs_List$success <- c(SIDs_List$success, FALSE)
+
+      # Return NULL for this identifier to indicate failure
+      NULL
+    })
+    return(response)
+  })
+
+  # Store the results in the SIDs_List object
+  SIDs_List$result <- result
+
+  # Return the structured object with results and error details
   structure(
     SIDs_List,
     class = c("PubChemInstance_SIDs")
